%% Matlab tutorial 2
% (c) 2011 David Weiss
% Solutions for the Session 2 programming task.
%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%
data = load('carbig');

disp(['mean MPG: ' num2str(mean(data.MPG))]);

% what! NaN values! we must remove them!

%% remove NaN MPG measurements

% do some basic data analysis:

nanidx = find(isnan(data.MPG));
data.Model(nanidx,:)

% let's remove those rows from EVERY field!
fields = fieldnames(data);
for i = 1:numel(fields)
    f = data.(fields{i});
    f(nanidx,:) = [];
    data.(fields{i}) = f;
end

disp(['mean MPG: ' num2str(mean(data.MPG))]);

%% now look for correlations

% let's look for correlations between variables.
[rho pvalue] = corr(data.MPG, [data.Cylinders data.Displacement data.Horsepower data.Weight data.Acceleration])

% blast! more Nan values!

%% remove ALL NaN's

data = load('carbig');

matrix_version = [data.MPG data.Cylinders data.Displacement data.Horsepower data.Weight data.Acceleration data.Model_Year];
nan_rows = any(isnan(matrix_version), 2);
nanidx = find(nan_rows);

% let's remove those rows from EVERY field!
fields = fieldnames(data);
for i = 1:numel(fields)
    f = data.(fields{i});
    f(nanidx,:) = [];
    data.(fields{i}) = f;
end

%% 
[rho pvalue] = corr(data.MPG, [data.Cylinders data.Displacement data.Horsepower data.Weight data.Acceleration data.Model_Year])

%% play with data plots
plot(data.Weight, data.MPG, 'o');

%% Get a breakdown of countries of origin
[countries first_row country_row] = unique(data.org, 'rows')

boxplot(data.MPG, country_row, 'labels', countries);
ylabel('MPG');
title('MPG by Country');

%% Statistics fun! (Not necesary for CIS520) 

% Computing t-tests between specific countries
usa_rows = strmatch('USA', data.org);
jap_rows = strmatch('Japan', data.org);
eur_rows = strmatch('Europe', data.org);

[h p] = ttest2(data.MPG(usa_rows), data.MPG(jap_rows), [], [], 'unequal');
disp(['USA vs. Japan: ' num2str(p)]);

[h p] = ttest2(data.MPG(eur_rows), data.MPG(jap_rows), [], [], 'unequal');
disp(['Europe vs. Japan: ' num2str(p)]);

%% Our custom fancy plotting function.
plot_by_country(data, 'Weight');

%% Compute correlation of being USA with other values
[rho pvalue] = corr(country_row==3, [data.Cylinders data.Displacement data.Horsepower data.Weight data.Acceleration data.Model_Year]);
rho
pvalue


%% Important Advanced Concepts
%%%%%%%%%%%%%%

%% 1 Using repmat for vectorization

% example: Scale each column to 0-1.

A = rand(10, 5);

% Subtract the min of each column
minA = repmat(min(A), 10, 1);
A = A - minA;

% Divide by max of each column
maxA = repmat(max(A), 10, 1);
A = A ./ maxA;

%% 2 Using bsxfun to do the same.

A = rand(10, 5);

% bsxfun or "binary singleton expansion function" automatically repmat's
% across the SINGLETON dimension (i.e. since min(A) is a row vector,
% operates across A's rows)
A = bsxfun(@minus, A, min(A));
A = bsxfun(@rdivide, A, max(A));

% The @ means "give me a handle to a function." 
f = @minus;
f(A, 2) % this is the same as minus(A,2) which is the same as A - 2

%% 3 Using get() and set() for advanced graph customization.

% h is a handle to the LINES that the data is plotted on.
h = plot(sin(-pi:0.1:pi));

get(h) % to see a list of properties
set(h, 'LineWidth', 5) % to override properties

% use GCA to Get a handle to the Current Axis
set(gca,'XTick', [1 25 50]) % to override properties


















