function plot_by_country(data, xfield)
% Plots data with line fit broken down by country.

% Get breakdown of data structure by country.
[countries first_row country_row] = unique(data.org, 'rows');

clf;

% The colors of the data points
linespecs = {'ro','bx','g^'};
% The colors of the model fitting lines
linecolors = {'--r','--b','--g'};

% Get the X data from the specified field.
x = data.(xfield);

hold on;
for i = 1:3
    idx = find(country_row==i);
    
    % Plot the data for each country.
    plot(x(idx), data.MPG(idx),  linespecs{i});
    
    % Add a model fitting line for each country.
    [line_x, line_y] = get_fit_line(x(idx), data.MPG(idx));
    plot(line_x, line_y, linecolors{i}, 'LineWidth', 2);
end
hold off
legend(countries);
xlabel(xfield);
ylabel('MPG');
title([xfield ' vs. MPG (By Country)']);
